draws isometric curves for the entropy by calculating the entropy for all points in a grid and connecting those within a epsilon enviroment of the value
iso_entropy_curve(x, ratio = 1, eps = 0.001, grid_granularity = 0.01)numeric, is the offset for the points
numeric, is the ratio
numeric, the epsilon for entropies to be selected
numeric between 0 and 1, defines the granularity of the grid