symmetric_distance: X symmetric distance of a point
Description
calculates the Distance from the positive anchor and the negative anchor
to the point and returns the smaller one. That means, if y is positive the distance to
the positive anchor will be return, if it is negative,
the negative anchor distance will be calculated
Usage
symmetric_distance(x, y, anchor)
Arguments
x, y
numerical, in this case phi and delta but in general the input coordinates
anchor
vector (x,y) the anchor for the calculation of the distance
Value
the smaller distance of (x,y) to eather the positive or negative anchor